@@ -1125,9 +1125,13 @@ static gboolean on_treeview_button_press_event_advsearch(GtkWidget *
 							     user_data)
 {
 	if (event->button == 3) {
+#if GTK_CHECK_VERSION(3, 22, 0)
+		gtk_menu_popup_at_pointer((GtkMenu *)search1.menu_item_send_search, NULL);
+#else
 		gtk_menu_popup((GtkMenu *)search1.menu_item_send_search,
 			       NULL, NULL, NULL, NULL, 2,
 			       gtk_get_current_event_time());
+#endif
 		return TRUE;
 	} else {
 		return FALSE;
